@@ -12,7 +12,7 @@
     Digital oscillator algorithm originally coded by David Rowe, 5/11/97.
 
 	 Voicetronix Voice Processing Board (VPB) Software
-	 Copyright (C) 1997-2008 Voicetronix www.voicetronix.com.au
+	 Copyright (C) 1997-2018 Voicetronix www.voicetronix.com.au
 
 	 This library is free software; you can redistribute it and/or
 	 modify it under the terms of the GNU Lesser General Public
@@ -773,13 +773,16 @@ public:
 		    case ONESHOT:
 			m_state = IDLE;
 			pthread_cond_broadcast( &m_cond );
+			// fall through
 
 		    case SEQUENCE:
 			m_config->SignalCompletion(*this);
 			//XXX if there was no completion handler, then call DoStop?
 			//    that doesn't alway help cleaning up old Config data does it?
+			// fall through
 
-		    case IDLE: ;
+		    case IDLE:
+			break;
 		}
 	}
 	else if( __builtin_expect(m_state != IDLE,1) ) ImplStart();
