@@ -11,11 +11,25 @@
 \*-------------------------------------------------------------------------*/
 
 #include "four_sh3.h"
-#include "wind.h"
 #include "shift.h"
 #include "dftwin.h"
 #include "dft.h"
 
+// windows a Nsam vector of speech samples.
+static inline void window(int Wn[], int sn[], int Nsam, int window_table[],int nrsh)
+/*  int	 Wn[];			output frame of windowed samples	*/
+/*  int  sn[];			input frame of speech samples		*/
+/*  int	 Nsam;			number of samples			*/
+/*  int	 window_table[];	LOOK-UP TABLE				*/
+/*  int  nrsh;			number of right shifts	(only)		*/
+{
+    /* nrsh = 18 for hanning, and 15 for DFT 	*/
+
+    int i = 0;
+    for(; i<Nsam; ++i)
+	Wn[i] = (long)sn[i] * (long)window_table[i] >> nrsh; /*(1l<<15);*/
+}
+
 /*--------------------------------------------------------------------------*\
 
 	FUNCTION....: dft()
