@@ -743,7 +743,6 @@ int check_cadence(DETECT *d, unsigned short id, unsigned short logthis,
 /*  ushort  logthis;	asserted to log this call		*/
 {
     unsigned short  tone;	/* asserted if tone present		*/
-    unsigned short  ptone;	/* asserted if tone in prev frame	*/
     int     rising;	/* asserted on rising edge		*/
     int     falling;	/* asserted on falling edge		*/
     unsigned short  tone_on;	/* frames tone on			*/
@@ -760,7 +759,6 @@ int check_cadence(DETECT *d, unsigned short id, unsigned short logthis,
     /* load d variables into locals for convenience */
 
     tone = d->tone;
-    ptone = d->ptone;
     tone_on = d->tone_on;
     tone_off = d->tone_off;
     tone_glitch = d->tone_glitch;
