@@ -43,6 +43,7 @@
  #include "openpri.h"
 #endif
 
+#include <unistd.h>
 #include <cassert>
 #include <cstring>
 #include <cmath>
@@ -123,7 +124,7 @@ protected:
 
 	uint16_t    mess[PC_LTONEG_RESET] = { PC_LTONEG_RESET,
 					      PC_TONEG_RESET,
-					      GetConfig().GetUserData<int>(0) };
+					      uint16_t(GetConfig().GetUserData<int>(0)) };
 	m_comm->PutMessageVPB( m_cardnum, mess );
 
     } //}}}
@@ -321,8 +322,8 @@ void V4PCI_DSP::SetHookState( int port, HookState hookstate )
 	{
 	    case VPB_ONHOOK:
 	    {
-		uint16_t mess1[] = { PC_LCODEC_ONHK, PC_CODEC_ONHK, port };
-		uint16_t mess2[] = { PC_LCODEC_GEN, PC_CODEC_GEN, port, 0x12, 0x1c };
+		uint16_t mess1[] = { PC_LCODEC_ONHK, PC_CODEC_ONHK, uint16_t(port) };
+		uint16_t mess2[] = { PC_LCODEC_GEN, PC_CODEC_GEN, uint16_t(port), 0x12, 0x1c };
 
 		mprintf("[%d/%d] Set On Hook\n", m_reg.cardnum, port);
 		vpb_c->PutMessageVPB(m_reg.cardtypnum, mess1);
@@ -332,8 +333,8 @@ void V4PCI_DSP::SetHookState( int port, HookState hookstate )
 	    case VPB_OFFHOOK:
 	    case VPB_FASTOFFHOOK:
 	    {
-		uint16_t mess1[] = { PC_LCODEC_GEN, PC_CODEC_GEN, port, 0x12, 0x7c };
-		uint16_t mess2[] = { PC_LCODEC_OFFHK, PC_CODEC_OFFHK, port };
+		uint16_t mess1[] = { PC_LCODEC_GEN, PC_CODEC_GEN, uint16_t(port), 0x12, 0x7c };
+		uint16_t mess2[] = { PC_LCODEC_OFFHK, PC_CODEC_OFFHK, uint16_t(port) };
 
 		mprintf("[%d/%d] Set Off Hook\n", m_reg.cardnum, port);
 		vpb_c->PutMessageVPB(m_reg.cardtypnum, mess1);
