@@ -45,6 +45,7 @@
 #define	COMM_MAX_MESSPCDSP	128	// maximum message length from PC to DSP
 #define	COMM_EMPTY		2	// read failed as no messages		  
 
+#define V4PCI_LSF		160	// Length in samples of V4PCI superframe
 
 class Comm;
 
@@ -88,10 +89,8 @@ public:
 
     void SetHookState( int port, HookState hookstate );
 
-    void WaitForTxEmpty( int port )
-    { //{{{
-	while(m_reg.txdf[port]->HowFull() >= m_reg.lsf) usleep( 20 * 1000 );
-    } //}}}
+    void PadTxFrame( int port );
+    void WaitForTxEmpty( int port );
 
     void UNListen( unsigned int port );
 
