@@ -106,7 +106,7 @@ public:
 		     unsigned short length, uint16_t *buf);
 	void EeRead(unsigned short board, unsigned short addr,
 		    unsigned short length, uint16_t *buf);
-	void *GethndFile() {return (void*)hndFile;}
+	void *GethndFile() {return (void*)(intptr_t)hndFile;}
 	int  GetDeviceDriverModel() { return DeviceDriverModel; }
 };
 
