@@ -38,7 +38,6 @@ extern "C" {
 
 
 struct pri_chan {
-	pid_t pid;
 	int state;
 	int run;
 	int encoding;		// Encoding
@@ -56,6 +55,8 @@ struct pri_chan {
 	void *vox_states;       // Pointer to vox states
 	VPB_CALL_INFO *cid;
 	VPBREG *v;
+	float linear_play_gain;
+	float linear_record_gain;
 };
 
 typedef struct {
@@ -111,6 +112,7 @@ public:
 
 	void SetHookState( int port, HookState hookstate );
 
+	void PadTxFrame( int port );
 	void WaitForTxEmpty( int port );
 	void UNListen( unsigned int port );
 
