@@ -755,7 +755,7 @@ static void *play_file_async_thread(void *p)
 	PLAY_FILE_ASYNC_ARGS *args     = (PLAY_FILE_ASYNC_ARGS*)p;
 	int		     handle    = args->handle;
 
-	pthread_cleanup_push(play_file_thread_cleanup, (void*)handle);
+	pthread_cleanup_push(play_file_thread_cleanup, (void*)(intptr_t)handle);
 
 	WFILE	             *wout     = args->wout;
 	FILE	             *vout     = args->vout;
@@ -858,7 +858,7 @@ static void play_file(int handle,
 		//     this should only be needed during app shutdown then
 		//     we will tolerate it for now.  This should not be an
 		//     issue in later versions.
-		pthread_cleanup_push(play_file_thread_cleanup, (void*)handle);
+		pthread_cleanup_push(play_file_thread_cleanup, (void*)(intptr_t)handle);
 		playloop(handle, bytes, wout, vout, file_type);
 		Play::list[handle].state = VPB_AUDIO_TERMINATE_SYNC;
 		pthread_cleanup_pop(1);
@@ -1342,7 +1342,7 @@ static void *record_file_async_thread(void *p)
 	RECORD_FILE_ASYNC_ARGS *args      = (RECORD_FILE_ASYNC_ARGS*)p;
 	int			handle    = args->handle;
 
-	pthread_cleanup_push(record_file_thread_cleanup, (void*)handle);
+	pthread_cleanup_push(record_file_thread_cleanup, (void*)(intptr_t)handle);
 
 	WFILE		       *win       = args->win;
 	FILE		       *vin       = args->vin;
@@ -1448,7 +1448,7 @@ static void record_file(int handle,
 		//     this should only be needed during app shutdown then
 		//     we will tolerate it for now.  This should not be an
 		//     issue in later versions.
-		pthread_cleanup_push(record_file_sync_cleanup, (void*)handle);
+		pthread_cleanup_push(record_file_sync_cleanup, (void*)(intptr_t)handle);
 		recordloop(handle, bytes, win, vin, file_type);
 		pthread_cleanup_pop(0);
 	}
