@@ -242,6 +242,14 @@ public:
 		(void)impedance;
 	} //}}}
 
+        //! Configure the hook-flash detection window
+        virtual void SetFlashTime( int port, uint16_t min, uint16_t max)
+	{ //{{{
+		(void)port;
+		(void)min;
+		(void)max;
+	} //}}}
+
     //@} //}}}
 
     //! @name Port state
