@@ -214,7 +214,7 @@ static void dft(COMPLX *data, int samples)
 
 
 //! Determines the frequency of a tone or tone pair from a buffer of audio samples.
-static int determine_frequency( TRAIN *train, short *buf, int nsam )
+static int determine_frequency( TRAIN *train, short *buf )
 { //{{{
 	int	i,j;
 	COMPLX	x[NFFT];
@@ -226,11 +226,7 @@ static int determine_frequency( TRAIN *train, short *buf, int nsam )
 	float	Ewin,Etd;
 	int	bmin = (int)floor(FMIN/r+0.5);
 	int	bmax = (int)floor(FMAX/r+0.5);
-	int	start_cadence=0;
 
-	if ( train->nCadMark>1){
-		start_cadence=1;
-	}
 	// extract samples, window, and FFT
 
 	// start is the time of the first cadence * Sample rate
@@ -468,7 +464,7 @@ static int do_train( VPB_DETECT *tone, TRAIN *train, short *buf, int nsam )
 	// But we seem to be only performing a single frequency
 	// determination
 	if (train->nCadMark) {
-		ret = determine_frequency(train, buf, nsam);
+		ret = determine_frequency(train, buf);
 		if (ret != TRAIN_OK)
 			return ret;
 	}
