@@ -199,7 +199,7 @@ int main(int argc, char *argv[])
 			int h = vpb_open(i,j);
 
 			vpb_record_set(h, record);
-			pthread_create(&port_threads[x++], NULL, port_thread, (void*)h);
+			pthread_create(&port_threads[x++], NULL, port_thread, (void*)(intptr_t)h);
 
 			//int y = arg_exists(argc, argv, "--hookthreshold");
 			//if( y != 0 && (y+1) < argc)
