@@ -36,8 +36,8 @@
 
          Voicetronix Voice Processing Board (VPB) Software
 
-         Copyright (C) 1999-2013 Voicetronix www.voicetronix.com.au
-         Copyright (C) 2006-2013 Ron Lee <ron@voicetronix.com.au>
+         Copyright (C) 1999-2018 Voicetronix www.voicetronix.com.au
+         Copyright (C) 2006-2018 Ron Lee <ron@voicetronix.com.au>
 
          This library is free software; you can redistribute it and/or
          modify it under the terms of the GNU General Public License
@@ -113,14 +113,13 @@
 //#include "iic.h"		// s/w IIC emulation
 #include "iic.c"
 #include <asm/segment.h>
-#include <asm/uaccess.h>
 #include <linux/module.h>
 #include <linux/kernel.h>
 #include <asm/io.h>
 #include <linux/vmalloc.h>
 #include <linux/pci.h>
 #include <linux/delay.h>
-#include <asm/uaccess.h>
+#include <linux/uaccess.h>
 
 
 #if LINUX_VERSION_CODE > KERNEL_VERSION(2,4,9)
