@@ -5,7 +5,7 @@
 	Date: 	21 June 2006
 
 
-	Copyright (C) 2006, 2007 Voicetronix www.voicetronix.com.au
+	Copyright (C) 2006 - 2013, Voicetronix www.voicetronix.com.au
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
@@ -92,14 +92,6 @@
  #define mutex_unlock(x)		up(x)
 #endif
 
-// struct proc_dir_entry dropped its owner field in Linus' tree at commit
-// 99b76233803beab302123d243eea9e41149804f3.
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,30)
- #define set_proc_owner(p,o)            (p)->owner = o;
-#else
- #define set_proc_owner(p,o)
-#endif
-
 /* boolean return values */
 #define RET_OK   1
 #define RET_FAIL 0
