@@ -5,8 +5,8 @@
 	        Ron Lee, 8 Jun 2006
 
 
-	Copyright (C) 2005 - 2013, Voicetronix www.voicetronix.com.au
-	Copyright (C) 2006 - 2013, Ron Lee <ron@voicetronix.com.au>
+	Copyright (C) 2005 - 2018, Voicetronix www.voicetronix.com.au
+	Copyright (C) 2006 - 2018, Ron Lee <ron@voicetronix.com.au>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
@@ -52,7 +52,7 @@
 #include <linux/proc_fs.h>
 #include <linux/seq_file.h>
 #include <linux/sched.h>
-#include <asm/uaccess.h>
+#include <linux/uaccess.h>
 
 #include "vtcore_ioctl.h"
 #include "vtmodule.h"
