@@ -159,10 +159,8 @@ void vt_write(struct vtboard *board);
 void vt_read(struct vtboard *board);
 int vt_send_event(struct vtboard *board, char *mess, int size);
 
-int vt_proc_read_int(char *page, char **start, off_t off,
-		     int count, int *eof, void *data);
-int vt_proc_read_string(char *page, char **start, off_t off,
-			int count, int *eof, void *data);
-int vt_create_board_proc_const_int(struct vtboard *board, const char *node, long val);
+const struct file_operations vt_int_proc_fops;
+const struct file_operations vt_string_proc_fops;
+void vt_create_board_proc_const_int(struct vtboard *board, const char *node, long val);
 
 #endif
