@@ -4,8 +4,8 @@
 	Author: Ben Kramer, 24 October 2005
 	        Ron Lee, 8 Jun 2006
 
-	Copyright (C) 2005 - 2013 Voicetronix www.voicetronix.com.au
-	Copyright (C) 2006 - 2013 Ron Lee <ron@voicetronix.com.au>
+	Copyright (C) 2005 - 2018 Voicetronix www.voicetronix.com.au
+	Copyright (C) 2006 - 2018 Ron Lee <ron@voicetronix.com.au>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
@@ -47,7 +47,7 @@
 #include <linux/delay.h>
 #include <linux/proc_fs.h>
 #include <linux/interrupt.h>
-#include <asm/uaccess.h>
+#include <linux/uaccess.h>
 
 #if VERBOSE_TIMING
  #include <asm/msr.h>          // for rdtscll, cputime.h is overkill here.
