@@ -11,8 +11,8 @@
 	    Peter Wintulich, 2003.
 
 
-	 Copyright (C) 2005 - 2013 Voicetronix www.voicetronix.com.au
-	 Copyright (C) 2006 - 2013, Ron Lee <ron@voicetronix.com.au>
+	 Copyright (C) 2005 - 2018 Voicetronix www.voicetronix.com.au
+	 Copyright (C) 2006 - 2018, Ron Lee <ron@voicetronix.com.au>
 
          This library is free software; you can redistribute it and/or
          modify it under the terms of the GNU General Public License
@@ -49,7 +49,7 @@
 #include <linux/pci.h>
 #include <linux/delay.h>
 #include <linux/interrupt.h>
-#include <asm/uaccess.h>
+#include <linux/uaccess.h>
 
 #include "vtcommon.h"
 #include "vtcore_ioctl.h"
