@@ -283,7 +283,7 @@ int main(void)
 		}
 	}
 	if(numboards==0) {
-		printf("Cannot find any VoiceTronix boards!\n");
+		printf("Cannot find any Voicetronix boards.\n");
 		return 255;
         } else {
 		printf("BOARDS:%d\n",numboards);
